@@ -1,7 +1,8 @@
-__all__ = ['Day', 'Month']
+__all__ = ['Day', 'Month', 'Date']
 
 from enum import Enum
-from pydantic import BaseModel, validator
+from pydantic import BaseModel, validator, Field
+from fastapi import Form
 from typing import Union
 
 
@@ -42,8 +43,7 @@ class Day(int, Enum):
     Dia31 = 31
 
 
-class Month(BaseModel):
-    data: Union[str, int]
+class Month(object):
 
     class Integer(int, Enum):
         '''
@@ -76,8 +76,8 @@ class Month(BaseModel):
         NOV = 'Novembro'
         DEC = 'Dezembro'
 
-    @validator('data')
-    def validate_data(cls, v) -> str:
+    @classmethod
+    def flip(cls, v) -> str:
         if isinstance(v, int):
             if v == 1: return cls.String.JAN.value
             elif v == 2: return cls.String.FEV.value
@@ -92,3 +92,7 @@ class Month(BaseModel):
             elif v == 11: return cls.String.NOV.value
             elif v == 12: return cls.String.DEC.value
 
+
+class Date(BaseModel):
+    day: Day = Field(...)
+    month: Month.String = Field(...)
\ No newline at end of file
